import { actionFromJSON, actionToJSON } from "./claim_record";
import { Timestamp } from "../../../google/protobuf/timestamp";
import { Duration } from "../../../google/protobuf/duration";
import * as _m0 from "protobufjs/minimal";
import { isSet, toTimestamp, fromTimestamp, fromJsonTimestamp } from "@osmonauts/helpers";

function createBaseClaimAuthorization() {
  return {
    contractAddress: "",
    action: 0
  };
}

export const ClaimAuthorization = {
  encode(message, writer = _m0.Writer.create()) {
    if (message.contractAddress !== "") {
      writer.uint32(10).string(message.contractAddress);
    }

    if (message.action !== 0) {
      writer.uint32(16).int32(message.action);
    }

    return writer;
  },

  decode(input, length) {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseClaimAuthorization();

    while (reader.pos < end) {
      const tag = reader.uint32();

      switch (tag >>> 3) {
        case 1:
          message.contractAddress = reader.string();
          break;

        case 2:
          message.action = reader.int32();
          break;

        default:
          reader.skipType(tag & 7);
          break;
      }
    }

    return message;
  },

  fromJSON(object) {
    return {
      contractAddress: isSet(object.contractAddress) ? String(object.contractAddress) : "",
      action: isSet(object.action) ? actionFromJSON(object.action) : 0
    };
  },

  toJSON(message) {
    const obj = {};
    message.contractAddress !== undefined && (obj.contractAddress = message.contractAddress);
    message.action !== undefined && (obj.action = actionToJSON(message.action));
    return obj;
  },

  fromPartial(object) {
    var _object$contractAddre, _object$action;

    const message = createBaseClaimAuthorization();
    message.contractAddress = (_object$contractAddre = object.contractAddress) !== null && _object$contractAddre !== void 0 ? _object$contractAddre : "";
    message.action = (_object$action = object.action) !== null && _object$action !== void 0 ? _object$action : 0;
    return message;
  }

};

function createBaseParams() {
  return {
    airdropEnabled: false,
    airdropStartTime: undefined,
    durationUntilDecay: undefined,
    durationOfDecay: undefined,
    claimDenom: "",
    allowedClaimers: []
  };
}

export const Params = {
  encode(message, writer = _m0.Writer.create()) {
    if (message.airdropEnabled === true) {
      writer.uint32(8).bool(message.airdropEnabled);
    }

    if (message.airdropStartTime !== undefined) {
      Timestamp.encode(toTimestamp(message.airdropStartTime), writer.uint32(18).fork()).ldelim();
    }

    if (message.durationUntilDecay !== undefined) {
      Duration.encode(message.durationUntilDecay, writer.uint32(26).fork()).ldelim();
    }

    if (message.durationOfDecay !== undefined) {
      Duration.encode(message.durationOfDecay, writer.uint32(34).fork()).ldelim();
    }

    if (message.claimDenom !== "") {
      writer.uint32(42).string(message.claimDenom);
    }

    for (const v of message.allowedClaimers) {
      ClaimAuthorization.encode(v, writer.uint32(50).fork()).ldelim();
    }

    return writer;
  },

  decode(input, length) {
    const reader = input instanceof _m0.Reader ? input : new _m0.Reader(input);
    let end = length === undefined ? reader.len : reader.pos + length;
    const message = createBaseParams();

    while (reader.pos < end) {
      const tag = reader.uint32();

      switch (tag >>> 3) {
        case 1:
          message.airdropEnabled = reader.bool();
          break;

        case 2:
          message.airdropStartTime = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
          break;

        case 3:
          message.durationUntilDecay = Duration.decode(reader, reader.uint32());
          break;

        case 4:
          message.durationOfDecay = Duration.decode(reader, reader.uint32());
          break;

        case 5:
          message.claimDenom = reader.string();
          break;

        case 6:
          message.allowedClaimers.push(ClaimAuthorization.decode(reader, reader.uint32()));
          break;

        default:
          reader.skipType(tag & 7);
          break;
      }
    }

    return message;
  },

  fromJSON(object) {
    return {
      airdropEnabled: isSet(object.airdropEnabled) ? Boolean(object.airdropEnabled) : false,
      airdropStartTime: isSet(object.airdropStartTime) ? fromJsonTimestamp(object.airdropStartTime) : undefined,
      durationUntilDecay: isSet(object.durationUntilDecay) ? Duration.fromJSON(object.durationUntilDecay) : undefined,
      durationOfDecay: isSet(object.durationOfDecay) ? Duration.fromJSON(object.durationOfDecay) : undefined,
      claimDenom: isSet(object.claimDenom) ? String(object.claimDenom) : "",
      allowedClaimers: Array.isArray(object === null || object === void 0 ? void 0 : object.allowedClaimers) ? object.allowedClaimers.map(e => ClaimAuthorization.fromJSON(e)) : []
    };
  },

  toJSON(message) {
    const obj = {};
    message.airdropEnabled !== undefined && (obj.airdropEnabled = message.airdropEnabled);
    message.airdropStartTime !== undefined && (obj.airdropStartTime = message.airdropStartTime.toISOString());
    message.durationUntilDecay !== undefined && (obj.durationUntilDecay = message.durationUntilDecay);
    message.durationOfDecay !== undefined && (obj.durationOfDecay = message.durationOfDecay);
    message.claimDenom !== undefined && (obj.claimDenom = message.claimDenom);

    if (message.allowedClaimers) {
      obj.allowedClaimers = message.allowedClaimers.map(e => e ? ClaimAuthorization.toJSON(e) : undefined);
    } else {
      obj.allowedClaimers = [];
    }

    return obj;
  },

  fromPartial(object) {
    var _object$airdropEnable, _object$airdropStartT, _object$durationUntil, _object$durationOfDec, _object$claimDenom, _object$allowedClaime;

    const message = createBaseParams();
    message.airdropEnabled = (_object$airdropEnable = object.airdropEnabled) !== null && _object$airdropEnable !== void 0 ? _object$airdropEnable : false;
    message.airdropStartTime = (_object$airdropStartT = object.airdropStartTime) !== null && _object$airdropStartT !== void 0 ? _object$airdropStartT : undefined;
    message.durationUntilDecay = (_object$durationUntil = object.durationUntilDecay) !== null && _object$durationUntil !== void 0 ? _object$durationUntil : undefined;
    message.durationOfDecay = (_object$durationOfDec = object.durationOfDecay) !== null && _object$durationOfDec !== void 0 ? _object$durationOfDec : undefined;
    message.claimDenom = (_object$claimDenom = object.claimDenom) !== null && _object$claimDenom !== void 0 ? _object$claimDenom : "";
    message.allowedClaimers = ((_object$allowedClaime = object.allowedClaimers) === null || _object$allowedClaime === void 0 ? void 0 : _object$allowedClaime.map(e => ClaimAuthorization.fromPartial(e))) || [];
    return message;
  }

};